#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
NDL unit tests.
"""

from decomecha import DecoEngine

import unittest

class NDLTestCase(unittest.TestCase):
    """
    Tests for NDL calculation.
    """
    def test_ndl_vs_dive_time(self):
        """
        Test NDL is higher than dive time
        """
        deco = DecoEngine()
        deco.add_segment(20, 29)
        deco.add_gas(0, 21)
        info = deco.calculate()

        self.assertTrue(info.ndl > 29)


    def test_ndl_same_depth(self):
        """
        Test NDL for same depth
        """
        deco = DecoEngine()
        deco.add_segment(20, 30)
        deco.add_gas(0, 21)
        info = deco.calculate()
        ndl1 = info.ndl

        deco = DecoEngine()
        deco.add_segment(20, 10)
        deco.add_gas(0, 21)
        info = deco.calculate()
        ndl2 = info.ndl

        # NDL time is still the same as depth has not changed
        self.assertEquals(ndl1, ndl2)


    def test_zero_ndl_no_deco(self):
        """
        Test 0 minutes NDL at end of dive and no deco stops
        """
        deco = DecoEngine()
        deco.add_segment(20, 35)
        deco.add_gas(0, 21)
        info = deco.calculate()

        assert len(info.stops) == 0
        self.assertTrue(info.ndl > 0)


# vim: sw=4:et:ai
